@@ -1,4 +1,4 @@
-# Copyright (c) 2020, Djaodjin Inc.
+# Copyright (c) 2021, Djaodjin Inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -24,9 +24,10 @@
 
 from __future__ import unicode_literals
 
-import json, logging, random
+import datetime, json, logging, random
 from collections import OrderedDict
 
+from django.contrib.auth import get_user_model
 from django.db import IntegrityError, models, transaction
 from django.db.models import Max
 from django.template.defaultfilters import slugify
@@ -34,11 +35,21 @@ from django.utils.translation import ugettext_lazy as _
 from rest_framework.exceptions import ValidationError
 
 from . import settings
-from .compat import python_2_unicode_compatible
+from .compat import import_string, python_2_unicode_compatible, six
 
 
 LOGGER = logging.getLogger(__name__)
 
+
+def get_extra_field_class():
+    extra_class = settings._SETTINGS.get('EXTRA_FIELD')
+    if extra_class is None:
+        extra_class = models.TextField
+    elif isinstance(extra_class, str):
+        extra_class = import_string(extra_class)
+    return extra_class
+
+
 class RelationShipManager(models.Manager):
 
     def insert_available_rank(self, root, pos=0, node=None):
@@ -143,21 +154,35 @@ class PageElement(models.Model):
 
     slug = models.SlugField(unique=True,
         help_text=_("Unique identifier that can be used in URL paths"))
-    title = models.CharField(max_length=720, blank=True,
+    title = models.CharField(max_length=1024, blank=True,
         help_text=_("Title of the page element"))
     text = models.TextField(blank=True,
         help_text=_("Long description of the page element"))
     account = models.ForeignKey(
         settings.ACCOUNT_MODEL, related_name='account_page_element',
         null=True, on_delete=models.SET_NULL)
+    picture = models.URLField(_("URL to a icon picture"), max_length=2083,
+        null=True, blank=True, help_text=_("Icon picture"))
+    reading_time = models.DurationField(null=True,
+        default=datetime.timedelta,  # stored in microseconds
+        help_text=_("Reading time of the material (in hh:mm:ss)"))
+    lang = models.CharField(_("Language the material is written in"),
+         default=settings.LANGUAGE_CODE, max_length=5)
+    extra = get_extra_field_class()(null=True, blank=True)
     relationships = models.ManyToManyField("self",
         related_name='related_to', through='RelationShip', symmetrical=False)
-    tag = models.CharField(max_length=255, null=True, blank=True,
-        help_text=_("Extra meta data (can be stringify JSON)"))
 
     def __str__(self):
         return self.slug
 
+    @property
+    def nb_upvotes(self):
+        return Vote.objects.filter(element=self, vote=Vote.UP_VOTE).count()
+
+    @property
+    def nb_followers(self):
+        return Follow.objects.filter(element=self).count()
+
     def add_relationship(self, element, tag=None):
         rank = RelationShip.objects.filter(
             orig_element=self).aggregate(Max('rank')).get('rank__max', None)
@@ -192,7 +217,7 @@ class PageElement(models.Model):
             return [[self]]
         if hints:
             for parent in parents:
-                if parent.slug == hints[-1]:
+                if parent.slug == str(hints[-1]):
                     # we found a way to cut the search space early.
                     parents = [parent]
                     hints = hints[:-1]
@@ -206,7 +231,7 @@ class PageElement(models.Model):
                     term_index = 0
                     if hints:
                         for node in grandparent:
-                            if node.slug == hints[term_index]:
+                            if node.slug == str(hints[term_index]):
                                 term_index += 1
                                 if term_index >= len(hints):
                                     break
@@ -260,6 +285,129 @@ class PageElement(models.Model):
             "Unable to create a unique URL slug from title '%s'" % self.title})
 
 
+@python_2_unicode_compatible
+class Comment(models.Model):
+    """
+    A user comments about a PageElement.
+    """
+    created_at = models.DateTimeField(_('date/time submitted'),
+        default=None, db_index=True)
+    text = models.TextField(_('text'), max_length=settings.COMMENT_MAX_LENGTH)
+
+    ip_address = models.GenericIPAddressField(_('IP address'),
+        unpack_ipv4=True, blank=True, null=True)
+    user = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name=_('user'),
+        related_name="%(class)s_comments", on_delete=models.CASCADE)
+    element = models.ForeignKey(PageElement, on_delete=models.CASCADE,
+        related_name='comments')
+
+    def __str__(self):
+        return str(self.text)
+
+
+class FollowManager(models.Manager):
+
+    @staticmethod
+    def get_followers(element):
+        """
+        Get a list of followers for a Element.
+        """
+        return get_user_model().objects.filter(follows__element=element)
+
+    def subscribe(self, element, user):
+        """
+        Subscribe a User to changes to a Element.
+        """
+        self.get_or_create(user=user, element=element)
+
+    def unsubscribe(self, element, user):
+        """
+        Unsubscribe a User from changes to a Element.
+        """
+        try:
+            self.get(user=user, element=element).delete()
+        except models.ObjectDoesNotExist:
+            pass
+
+
+
+@python_2_unicode_compatible
+class Follow(models.Model):
+    """
+    A relationship intended for a User to follow comments on a Element.
+    """
+    objects = FollowManager()
+
+    created_at = models.DateTimeField(editable=False, auto_now_add=True)
+    user = models.ForeignKey(settings.AUTH_USER_MODEL, db_column='user_id',
+         related_name='follows', on_delete=models.CASCADE)
+    element = models.ForeignKey(PageElement,
+        related_name='followers', on_delete=models.CASCADE)
+
+    class Meta:
+        unique_together = (('user', 'element'),)
+
+    def __str__(self):
+        return u'%s follows %s' % (self.user, self.element)
+
+
+class VoteManager(models.Manager):
+
+    def vote_up(self, element, user):
+        """
+        Vote a Element up by a User.
+        """
+        vote, created = self.get_or_create(user=user, element=element,
+            defaults={'vote': Vote.UP_VOTE})
+        if not created:
+            vote.vote = Vote.UP_VOTE
+            vote.save()
+
+    def vote_down(self, element, user):
+        """
+        Vote a Element down by a User.
+        """
+        vote, created = self.get_or_create(user=user, element=element,
+            defaults={'vote': Vote.DOWN_VOTE})
+        if not created:
+            vote.vote = Vote.DOWN_VOTE
+            vote.save()
+
+
+@python_2_unicode_compatible
+class Vote(models.Model):
+    """
+    A vote on an element by a User.
+    """
+    objects = VoteManager()
+
+    UP_VOTE = 1
+    DOWN_VOTE = -1
+    SCORES = (
+        (UP_VOTE, u'+1'),
+        (DOWN_VOTE, u'-1'),
+    )
+
+    created_at = models.DateTimeField(editable=False, auto_now_add=True)
+    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE)
+    element = models.ForeignKey(PageElement,
+        related_name='votes', on_delete=models.CASCADE)
+    vote = models.SmallIntegerField(choices=SCORES)
+
+    class Meta:
+        # One vote per user per Element
+        unique_together = (('user', 'element'),)
+
+    def __str__(self):
+        return u'%s: %s on %s' % (self.user, self.vote, self.element)
+
+    def is_upvote(self):
+        return self.vote == self.UP_VOTE
+
+    def is_downvote(self):
+        return self.vote == self.DOWN_VOTE
+
+
 @python_2_unicode_compatible
 class MediaTag(models.Model):
 
@@ -362,12 +510,14 @@ def build_content_tree(roots=None, prefix=None, cut=None):
             slug = root.slug
             orig_element_id = root.pk
             title = root.title
-            extra = root.tag
+            picture = root.picture
+            extra = root.extra
         else:
             slug = root.get('slug', root.get('dest_element__slug'))
             orig_element_id = root.get('dest_element__pk')
             title = root.get('dest_element__title')
-            extra = root.get('dest_element__tag')
+            picture = root.get('dest_element__picture')
+            extra = root.get('dest_element__extra')
         leaf_slug = '/%s' % slug
         if prefix.endswith(leaf_slug):
             # Workaround because we sometimes pass a prefix and sometimes
@@ -393,9 +543,9 @@ def build_content_tree(roots=None, prefix=None, cut=None):
     args = tuple([])
     edges = RelationShip.objects.filter(
         orig_element__in=roots_after_cut).values(
-        'orig_element_id', 'dest_element_id', 'rank',
-        'dest_element__slug', 'dest_element__title',
-        'dest_element__tag', *args).order_by('rank', 'pk')
+        'orig_element_id', 'dest_element_id', 'rank', 'dest_element__slug',
+        'dest_element__extra', 'dest_element__picture', 'dest_element__title',
+        *args).order_by('rank', 'pk')
     while edges:
         next_pks_to_leafs = {}
         for edge in edges:
@@ -404,12 +554,15 @@ def build_content_tree(roots=None, prefix=None, cut=None):
             slug = edge.get('slug', edge.get('dest_element__slug'))
             base = pks_to_leafs[orig_element_id]['path'] + "/" + slug
             title = edge.get('dest_element__title')
-            extra = edge.get('dest_element__tag')
+            picture = edge.get('dest_element__picture')
+            extra = edge.get('dest_element__extra')
             try:
                 extra = json.loads(extra)
             except (TypeError, ValueError):
                 pass
             result_node = {'title': title}
+            if picture:
+                result_node.update({'picture': picture})
             if extra:
                 result_node.update({'extra': extra})
             text = edge.get('dest_element__text', None)
@@ -426,9 +579,26 @@ def build_content_tree(roots=None, prefix=None, cut=None):
         next_pks_to_leafs = {}
         edges = RelationShip.objects.filter(
             orig_element_id__in=pks_to_leafs.keys()).values(
-            'orig_element_id', 'dest_element_id', 'rank',
-            'dest_element__slug', 'dest_element__title',
-            'dest_element__tag', *args).order_by('rank', 'pk')
+            'orig_element_id', 'dest_element_id', 'rank', 'dest_element__slug',
+            'dest_element__extra', 'dest_element__picture',
+            'dest_element__title', *args).order_by('rank', 'pk')
+    return results
+
+
+def flatten_content_tree(roots, depth=0):
+    """
+    Transforms a tree into a list with ``indent`` as the depth of a node
+    in the original tree.
+    """
+    results = []
+    for key, values in six.iteritems(roots):
+        elem, nodes = values
+        elem.update({
+            'path': key,
+            'indent': depth
+        })
+        results += [elem]
+        results += flatten_content_tree(nodes, depth=depth + 1)
     return results
 
 
@@ -437,11 +607,5 @@ def get_active_theme():
     Returns the active theme from a request.
     """
     if settings.ACTIVE_THEME_CALLABLE:
-        from .compat import import_string  # Because AppRegistryNotReady
-        theme_slug = import_string(settings.ACTIVE_THEME_CALLABLE)()
-        LOGGER.debug("pages: get_active_theme('%s')", theme_slug)
-        try:
-            return ThemePackage.objects.get(slug=theme_slug)
-        except ThemePackage.DoesNotExist:
-            pass
-    return None
+        return import_string(settings.ACTIVE_THEME_CALLABLE)()
+    return settings.APP_NAME
