@@ -9,7 +9,6 @@
 
 (function ($) {
     "use strict";
-    var preventClick = false;
 
     function BaseEditor(element, options){
         var self = this;
@@ -98,7 +97,6 @@
     $.fn.baseEditor = function(options, custom){
         var opts = $.extend( {}, $.fn.baseEditor.defaults, options );
         return this.each(function() {
-            console.log("attach editor to", this);
             $(this).data("editor", new BaseEditor($(this), opts));
         });
     };
@@ -106,6 +104,7 @@
     $.fn.baseEditor.defaults = {
         baseUrl: null, // Url to send request to server
         uniqueIdentifier: "id",
+        hints: null,
         onSuccess: function(element, resp){
             return true;
         },
@@ -137,16 +136,6 @@
             self.$el.on("mouseover mouseleave", function(event){
                 self.hoverElement(event);
             });
-
-            $(".editable").bind("hallomodified", function(event, data) {
-                $("#modified").html(gettext("Editables modified"));
-            });
-            if (self.options.preventBlurOnClick !== ""){
-                $(document).on("mousedown", self.options.preventBlurOnClick, function(event){
-                    event.stopPropagation();
-                    preventClick = true;
-                });
-            }
             if( self.options.focus ) {
                 self.toggleEdition();
             }
@@ -222,8 +211,11 @@
                     text: savedText
                 };
             }
+            if( self.options.hints ) {
+                data['hints'] = self.options.hints;
+            }
 
-            if( self.options.debug ){
+            if( self.options.debug ) {
                 console.log("data-key:", self.$el.attr("data-key"),
                     "send:", data);
             }
@@ -353,19 +345,62 @@
 
         markdownTools: function(){
             var self = this;
-            self.$mardownToolHtml = $("<div id=\"markdown_tool_" + self.getId() + "\" class=\"" + self.options.container_tool_class + "\">\
+            if( !self.$mardownToolHtml ) {
+                self.$mardownToolHtml = $("<div id=\"markdown_tool_" + self.getId() + "\" class=\"" + self.options.container_tool_class + "\">\
                                 <button type=\"button\" class=\"" + self.options.btn_tool_class + " markdown-h3\">H3</button>\
                                 <button type=\"button\" class=\"" + self.options.btn_tool_class + " markdown-h4\">H4</button>\
                                 <button type=\"button\" class=\"" + self.options.btn_tool_class + " markdown-bold\"><strong>B</strong></button>\
                                 <button type=\"button\" class=\"" + self.options.btn_tool_class + " markdown-italic\"><em>I</em></button>\
                                 <button type=\"button\" class=\"" + self.options.btn_tool_class + " markdown-list-ul\">List</button>\
                                 <button type=\"button\" class=\"" + self.options.btn_tool_class + " markdown-link\">Link</button></div>");
+                self.$mardownToolHtml.on("mousedown", function(event){
+                    event.preventDefault();
+                    var $target = $(event.target);
+                    if ($target.hasClass("markdown-h3")){
+                        self.$textarea.selection("insert", {text: "###", mode: "before"}).selection("insert", {text: "", mode: "after"});
+                    }else if($target.hasClass("markdown-h4")){
+                        self.$textarea.selection("insert", {text: "####", mode: "before"}).selection("insert", {text: "", mode: "after"});
+                    }else if($target.hasClass("markdown-bold")||$target.parent().hasClass("markdown-bold")){
+                        self.$textarea.selection("insert", {text: "**", mode: "before"}).selection("insert", {text: "**", mode: "after"});
+                    }else if($target.hasClass("markdown-list-ul")){
+                        self.$textarea.selection("insert", {text: "* ", mode: "before"}).selection("insert", {text: "", mode: "after"});
+                    }else if($target.hasClass("markdown-link")){
+                        var text = self.$textarea.selection();
+                        if (text.indexOf("http://") >= 0){
+                            self.$textarea.selection("insert", {text: "[" + text + "](", mode: "before"}).selection("insert", {text: ")", mode: "after"});
+                        }else{
+                            self.$textarea.selection("insert", {text: "[http://" + text + "](http://", mode: "before"}).selection("insert", {text: ")", mode: "after"});
+                        }
+                    }else if($target.attr("id") === "italic"){
+                        self.$textarea.selection("insert", {text: "*", mode: "before"}).selection("insert", {text: "*", mode: "after"});
+                    }
+                });
+            }
             return self.$mardownToolHtml;
         },
 
         textArea: function(){
             var self = this;
-            self.$textarea = $("<textarea placeholder=\"" + self.options.emptyInputText + "\" class=\"djaodjin-editor\" id=\"textarea_" + self.getId() + "\" style=\"\"></textarea>");
+            if( !self.$textarea ) {
+                self.$textarea = $("<textarea placeholder=\"" + self.options.emptyInputText + "\" class=\"djaodjin-editor\" id=\"textarea_" + self.getId() + "\" style=\"\"></textarea>");
+            }
+            // adds the handlers back always because `replaceWith` removes them.
+            self.$textarea.on("blur", function(event){
+                event.preventDefault();
+                self.saveEdition();
+            });
+            self.$textarea.droppable({
+                drop: function(event, ui){
+                    var droppable = $(this);
+                    var draggable = ui.draggable;
+                    droppable.focus();
+                    droppable.selection("insert", {
+                        text: "![Alt text](" + draggable.attr("src") + ")",
+                        mode: "before"
+                    });
+                    $(ui.helper).remove();
+                }
+            });
             return self.$textarea;
         },
 
@@ -412,59 +447,14 @@
         initEditor: function(){
             var self = this;
             self.getProperties();
-            self.markdownTools();
-            $("body").append(self.$mardownToolHtml);
+            $("body").append(self.markdownTools());
             self.$mardownToolHtml.css({
                 top: (self.$el.offset().top - 45) + "px",
                 left: self.$el.offset().left + "px"
             });
+            self.$mardownToolHtml.show();
             self.$el.replaceWith(self.textArea());
             self.$textarea.css(self.cssVar).val(self.originText).textareaAutoSize().focus();
-            if (!self.eventAttached){
-                $("body").on("blur", "#" + self.$textarea.attr("id"), function(){
-                    if (!preventClick){
-                        self.saveEdition();
-                    }else{
-                        $("#" + self.$textarea.attr("id")).focus();
-                        preventClick = false;
-                    }
-                });
-                $("body").on("mousedown", "#" + self.$mardownToolHtml.attr("id"), function(event){
-                    event.preventDefault();
-                    var $target = $(event.target);
-                    if ($target.hasClass("markdown-h3")){
-                        $("#" + self.$textarea.attr("id")).selection("insert", {text: "###", mode: "before"}).selection("insert", {text: "", mode: "after"});
-                    }else if($target.hasClass("markdown-h4")){
-                        $("#" + self.$textarea.attr("id")).selection("insert", {text: "####", mode: "before"}).selection("insert", {text: "", mode: "after"});
-                    }else if($target.hasClass("markdown-bold")||$target.parent().hasClass("markdown-bold")){
-                        $("#" + self.$textarea.attr("id")).selection("insert", {text: "**", mode: "before"}).selection("insert", {text: "**", mode: "after"});
-                    }else if($target.hasClass("markdown-list-ul")){
-                        $("#" + self.$textarea.attr("id")).selection("insert", {text: "* ", mode: "before"}).selection("insert", {text: "", mode: "after"});
-                    }else if($target.hasClass("markdown-link")){
-                        var text = $("#" + self.$textarea.attr("id")).selection();
-                        if (text.indexOf("http://") >= 0){
-                            $("#" + self.$textarea.attr("id")).selection("insert", {text: "[" + text + "](", mode: "before"}).selection("insert", {text: ")", mode: "after"});
-                        }else{
-                            $("#" + self.$textarea.attr("id")).selection("insert", {text: "[http://" + text + "](http://", mode: "before"}).selection("insert", {text: ")", mode: "after"});
-                        }
-                    }else if($target.attr("id") === "italic"){
-                        $("#" + self.$textarea.attr("id")).selection("insert", {text: "*", mode: "before"}).selection("insert", {text: "*", mode: "after"});
-                    }
-                });
-            }
-            $("#" + self.$textarea.attr("id")).droppable({
-                drop: function(event, ui){
-                    var droppable = $(this);
-                    var draggable = ui.draggable;
-                    droppable.focus();
-                    droppable.selection("insert", {
-                        text: "![Alt text](" + draggable.attr("src") + ")",
-                        mode: "before"
-                    });
-                    $(ui.helper).remove();
-                }
-            });
-            self.eventAttached = true;
         },
 
         getSavedText: function(){
@@ -477,9 +467,8 @@
             var convert = new Markdown.getSanitizingConverter().makeHtml;
             var newHtml = convert(self.getSavedText()).replace("<img ", "<img style=\"max-width:100%\" ");
             self.$textarea.replaceWith(self.$el.html(newHtml));
-            self.$textarea.remove();
-            self.$mardownToolHtml.remove();
-            self.init();
+            self.$mardownToolHtml.hide();
+            self.init(); // adds the handlers back to self.$el.
         },
 
         getOriginText: function(){
@@ -580,11 +569,7 @@
                 self.$valueSelector.attr("min", self.$el.data("range-min"))
                     .attr("max", self.$el.data("range-max"))
                     .attr("step", self.$el.data("range-step"))
-                    .val(self.originText).css({
-                        position: "absolute",
-                        width: self.$el.outerWidth(),
-                        left: self.$el.offset().left + "px"
-                    });
+                    .val(self.originText);
 
                 if (self.options.rangePosition === "middle"){
                     self.$valueSelector.css({top: (self.$el.offset().top + (self.$el.height() / 2)) + "px"});
@@ -619,9 +604,8 @@
 
     $.fn.editor.defaults = {
         baseUrl: null, // Url to send request to server
-        emptyInputText: gettext("placeholder, type to overwrite..."),
+        emptyInputText: "placeholder, type to overwrite...",
         uniqueIdentifier: "id",
-        preventBlurOnClick: "",
         onSuccess: function(element, resp){
             return true;
         },
